# Copyright (C) 2022 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
import fastapi
import pydantic

from .irequestprincipal import IRequestPrincipal


class NullRequestPrincipal(IRequestPrincipal, pydantic.BaseModel):

    @classmethod
    def depends(cls):
        return fastapi.Depends(cls)

    def is_anonymous(self) -> bool:
        return True

    def has_audience(self) -> bool:
        return False